from __future__ import annotations
from collections.abc import Callable
from dataclasses import dataclass, field
from kiota_abstractions.serialization import AdditionalDataHolder, Parsable, ParseNode, SerializationWriter
from typing import Any, Optional, TYPE_CHECKING, Union

@dataclass
class KeyContextResponse(AdditionalDataHolder, Parsable):
    # Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
    additional_data: dict[str, Any] = field(default_factory=dict)

    # The environmentId property
    environment_id: Optional[str] = None
    # The environmentName property
    environment_name: Optional[str] = None
    # The environmentSlug property
    environment_slug: Optional[str] = None
    # The keyId property
    key_id: Optional[str] = None
    # The projectId property
    project_id: Optional[str] = None
    # The projectName property
    project_name: Optional[str] = None
    # The projectSlug property
    project_slug: Optional[str] = None
    # The role property
    role: Optional[str] = None
    # The tenantId property
    tenant_id: Optional[str] = None
    # The tenantName property
    tenant_name: Optional[str] = None
    # The tenantSlug property
    tenant_slug: Optional[str] = None
    
    @staticmethod
    def create_from_discriminator_value(parse_node: ParseNode) -> KeyContextResponse:
        """
        Creates a new instance of the appropriate class based on discriminator value
        param parse_node: The parse node to use to read the discriminator value and create the object
        Returns: KeyContextResponse
        """
        if parse_node is None:
            raise TypeError("parse_node cannot be null.")
        return KeyContextResponse()
    
    def get_field_deserializers(self,) -> dict[str, Callable[[ParseNode], None]]:
        """
        The deserialization information for the current model
        Returns: dict[str, Callable[[ParseNode], None]]
        """
        fields: dict[str, Callable[[Any], None]] = {
            "environmentId": lambda n : setattr(self, 'environment_id', n.get_str_value()),
            "environmentName": lambda n : setattr(self, 'environment_name', n.get_str_value()),
            "environmentSlug": lambda n : setattr(self, 'environment_slug', n.get_str_value()),
            "keyId": lambda n : setattr(self, 'key_id', n.get_str_value()),
            "projectId": lambda n : setattr(self, 'project_id', n.get_str_value()),
            "projectName": lambda n : setattr(self, 'project_name', n.get_str_value()),
            "projectSlug": lambda n : setattr(self, 'project_slug', n.get_str_value()),
            "role": lambda n : setattr(self, 'role', n.get_str_value()),
            "tenantId": lambda n : setattr(self, 'tenant_id', n.get_str_value()),
            "tenantName": lambda n : setattr(self, 'tenant_name', n.get_str_value()),
            "tenantSlug": lambda n : setattr(self, 'tenant_slug', n.get_str_value()),
        }
        return fields
    
    def serialize(self,writer: SerializationWriter) -> None:
        """
        Serializes information the current object
        param writer: Serialization writer to use to serialize this model
        Returns: None
        """
        if writer is None:
            raise TypeError("writer cannot be null.")
        writer.write_str_value("environmentId", self.environment_id)
        writer.write_str_value("environmentName", self.environment_name)
        writer.write_str_value("environmentSlug", self.environment_slug)
        writer.write_str_value("keyId", self.key_id)
        writer.write_str_value("projectId", self.project_id)
        writer.write_str_value("projectName", self.project_name)
        writer.write_str_value("projectSlug", self.project_slug)
        writer.write_str_value("role", self.role)
        writer.write_str_value("tenantId", self.tenant_id)
        writer.write_str_value("tenantName", self.tenant_name)
        writer.write_str_value("tenantSlug", self.tenant_slug)
        writer.write_additional_data_value(self.additional_data)
    




from __future__ import annotations
from collections.abc import Callable
from dataclasses import dataclass, field
from kiota_abstractions.serialization import AdditionalDataHolder, Parsable, ParseNode, SerializationWriter
from typing import Any, Optional, TYPE_CHECKING, Union

@dataclass
class EnvironmentDriftItem(AdditionalDataHolder, Parsable):
    # Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
    additional_data: dict[str, Any] = field(default_factory=dict)

    # The envSpecific property
    env_specific: Optional[bool] = None
    # The inheritedIn property
    inherited_in: Optional[list[str]] = None
    # The isGlobal property
    is_global: Optional[bool] = None
    # The key property
    key: Optional[str] = None
    # The missingInSiblings property
    missing_in_siblings: Optional[list[str]] = None
    # The presentHere property
    present_here: Optional[bool] = None
    # The presentInSiblings property
    present_in_siblings: Optional[list[str]] = None
    
    @staticmethod
    def create_from_discriminator_value(parse_node: ParseNode) -> EnvironmentDriftItem:
        """
        Creates a new instance of the appropriate class based on discriminator value
        param parse_node: The parse node to use to read the discriminator value and create the object
        Returns: EnvironmentDriftItem
        """
        if parse_node is None:
            raise TypeError("parse_node cannot be null.")
        return EnvironmentDriftItem()
    
    def get_field_deserializers(self,) -> dict[str, Callable[[ParseNode], None]]:
        """
        The deserialization information for the current model
        Returns: dict[str, Callable[[ParseNode], None]]
        """
        fields: dict[str, Callable[[Any], None]] = {
            "envSpecific": lambda n : setattr(self, 'env_specific', n.get_bool_value()),
            "inheritedIn": lambda n : setattr(self, 'inherited_in', n.get_collection_of_primitive_values(str)),
            "isGlobal": lambda n : setattr(self, 'is_global', n.get_bool_value()),
            "key": lambda n : setattr(self, 'key', n.get_str_value()),
            "missingInSiblings": lambda n : setattr(self, 'missing_in_siblings', n.get_collection_of_primitive_values(str)),
            "presentHere": lambda n : setattr(self, 'present_here', n.get_bool_value()),
            "presentInSiblings": lambda n : setattr(self, 'present_in_siblings', n.get_collection_of_primitive_values(str)),
        }
        return fields
    
    def serialize(self,writer: SerializationWriter) -> None:
        """
        Serializes information the current object
        param writer: Serialization writer to use to serialize this model
        Returns: None
        """
        if writer is None:
            raise TypeError("writer cannot be null.")
        writer.write_bool_value("envSpecific", self.env_specific)
        writer.write_collection_of_primitive_values("inheritedIn", self.inherited_in)
        writer.write_bool_value("isGlobal", self.is_global)
        writer.write_str_value("key", self.key)
        writer.write_collection_of_primitive_values("missingInSiblings", self.missing_in_siblings)
        writer.write_bool_value("presentHere", self.present_here)
        writer.write_collection_of_primitive_values("presentInSiblings", self.present_in_siblings)
        writer.write_additional_data_value(self.additional_data)
    




from __future__ import annotations
from collections.abc import Callable
from dataclasses import dataclass, field
from kiota_abstractions.serialization import AdditionalDataHolder, Parsable, ParseNode, SerializationWriter
from typing import Any, Optional, TYPE_CHECKING, Union

@dataclass
class TenantUsageResponse(AdditionalDataHolder, Parsable):
    # Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
    additional_data: dict[str, Any] = field(default_factory=dict)

    # The currentMonth property
    current_month: Optional[str] = None
    # The estimatedOverageCost property
    estimated_overage_cost: Optional[float] = None
    # The freeMonthlyQuota property
    free_monthly_quota: Optional[int] = None
    # The isUnlimited property
    is_unlimited: Optional[bool] = None
    # The overageRatePerRequest property
    overage_rate_per_request: Optional[float] = None
    # The plan property
    plan: Optional[str] = None
    # The requestsRemaining property
    requests_remaining: Optional[int] = None
    # The requestsUsed property
    requests_used: Optional[int] = None
    
    @staticmethod
    def create_from_discriminator_value(parse_node: ParseNode) -> TenantUsageResponse:
        """
        Creates a new instance of the appropriate class based on discriminator value
        param parse_node: The parse node to use to read the discriminator value and create the object
        Returns: TenantUsageResponse
        """
        if parse_node is None:
            raise TypeError("parse_node cannot be null.")
        return TenantUsageResponse()
    
    def get_field_deserializers(self,) -> dict[str, Callable[[ParseNode], None]]:
        """
        The deserialization information for the current model
        Returns: dict[str, Callable[[ParseNode], None]]
        """
        fields: dict[str, Callable[[Any], None]] = {
            "currentMonth": lambda n : setattr(self, 'current_month', n.get_str_value()),
            "estimatedOverageCost": lambda n : setattr(self, 'estimated_overage_cost', n.get_float_value()),
            "freeMonthlyQuota": lambda n : setattr(self, 'free_monthly_quota', n.get_int_value()),
            "isUnlimited": lambda n : setattr(self, 'is_unlimited', n.get_bool_value()),
            "overageRatePerRequest": lambda n : setattr(self, 'overage_rate_per_request', n.get_float_value()),
            "plan": lambda n : setattr(self, 'plan', n.get_str_value()),
            "requestsRemaining": lambda n : setattr(self, 'requests_remaining', n.get_int_value()),
            "requestsUsed": lambda n : setattr(self, 'requests_used', n.get_int_value()),
        }
        return fields
    
    def serialize(self,writer: SerializationWriter) -> None:
        """
        Serializes information the current object
        param writer: Serialization writer to use to serialize this model
        Returns: None
        """
        if writer is None:
            raise TypeError("writer cannot be null.")
        writer.write_str_value("currentMonth", self.current_month)
        writer.write_float_value("estimatedOverageCost", self.estimated_overage_cost)
        writer.write_int_value("freeMonthlyQuota", self.free_monthly_quota)
        writer.write_bool_value("isUnlimited", self.is_unlimited)
        writer.write_float_value("overageRatePerRequest", self.overage_rate_per_request)
        writer.write_str_value("plan", self.plan)
        writer.write_int_value("requestsRemaining", self.requests_remaining)
        writer.write_int_value("requestsUsed", self.requests_used)
        writer.write_additional_data_value(self.additional_data)
    




from dataclasses import dataclass, field
from typing import Dict


@dataclass
class BaxterClientOptions:
    """Options for constructing a BaxterClient."""

    #: Base URL of the Baxter API (e.g. "https://baxter.example.com")
    baxter_url: str

    #: Bella Baxter API key (bax-...). Obtain via WebApp or: bella apikeys create
    api_key: str

    #: Request timeout in seconds (default: 10)
    timeout: float = 10.0


@dataclass
class AllEnvironmentSecretsResponse:
    """Response from GET /api/v1/environments/{slug}/secrets"""

    environment_slug: str
    environment_name: str
    #: All secrets for the environment, aggregated from all providers.
    #: Served from Baxter's Redis cache — does NOT hit AWS/Azure/GCP per call.
    secrets: Dict[str, str]
    #: Monotonically increasing version counter (unix timestamp of last mutation)
    version: int
    #: ISO-8601 timestamp of last mutation
    last_modified: str


@dataclass
class EnvironmentSecretsVersionResponse:
    """Response from GET /api/v1/environments/{slug}/secrets/version"""

    environment_slug: str
    version: int
    last_modified: str



from __future__ import annotations
from collections.abc import Callable
from dataclasses import dataclass, field
from kiota_abstractions.base_request_builder import BaseRequestBuilder
from kiota_abstractions.base_request_configuration import RequestConfiguration
from kiota_abstractions.default_query_parameters import QueryParameters
from kiota_abstractions.get_path_parameters import get_path_parameters
from kiota_abstractions.method import Method
from kiota_abstractions.request_adapter import RequestAdapter
from kiota_abstractions.request_information import RequestInformation
from kiota_abstractions.request_option import RequestOption
from kiota_abstractions.serialization import Parsable, ParsableFactory
from typing import Any, Optional, TYPE_CHECKING, Union
from warnings import warn

if TYPE_CHECKING:
    from .....models.get_project_response import GetProjectResponse
    from .....models.operation_response import OperationResponse
    from .....models.update_project_request import UpdateProjectRequest
    from .environments.environments_request_builder import EnvironmentsRequestBuilder
    from .export.export_request_builder import ExportRequestBuilder
    from .global_secret_provider.global_secret_provider_request_builder import GlobalSecretProviderRequestBuilder
    from .groups.groups_request_builder import GroupsRequestBuilder
    from .notifications.notifications_request_builder import NotificationsRequestBuilder
    from .providers.providers_request_builder import ProvidersRequestBuilder
    from .secrets.secrets_request_builder import SecretsRequestBuilder
    from .secret_drift.secret_drift_request_builder import SecretDriftRequestBuilder
    from .security.security_request_builder import SecurityRequestBuilder
    from .users.users_request_builder import UsersRequestBuilder
    from .webhooks.webhooks_request_builder import WebhooksRequestBuilder

class ItemRequestBuilder(BaseRequestBuilder):
    """
    Builds and executes requests for operations under /api/v1/projects/{-id}
    """
    def __init__(self,request_adapter: RequestAdapter, path_parameters: Union[str, dict[str, Any]]) -> None:
        """
        Instantiates a new ItemRequestBuilder and sets the default values.
        param path_parameters: The raw url or the url-template parameters for the request.
        param request_adapter: The request adapter to use to execute the requests.
        Returns: None
        """
        super().__init__(request_adapter, "{+baseurl}/api/v1/projects/{%2Did}", path_parameters)
    
    async def delete(self,request_configuration: Optional[RequestConfiguration[QueryParameters]] = None) -> Optional[OperationResponse]:
        """
        DELETE_api_v1_projects_projectRef
        param request_configuration: Configuration for the request such as headers, query parameters, and middleware options.
        Returns: Optional[OperationResponse]
        """
        request_info = self.to_delete_request_information(
            request_configuration
        )
        if not self.request_adapter:
            raise Exception("Http core is null") 
        from .....models.operation_response import OperationResponse

        return await self.request_adapter.send_async(request_info, OperationResponse, None)
    
    async def get(self,request_configuration: Optional[RequestConfiguration[QueryParameters]] = None) -> Optional[GetProjectResponse]:
        """
        GET_api_v1_projects_projectRef
        param request_configuration: Configuration for the request such as headers, query parameters, and middleware options.
        Returns: Optional[GetProjectResponse]
        """
        request_info = self.to_get_request_information(
            request_configuration
        )
        if not self.request_adapter:
            raise Exception("Http core is null") 
        from .....models.get_project_response import GetProjectResponse

        return await self.request_adapter.send_async(request_info, GetProjectResponse, None)
    
    async def put(self,body: UpdateProjectRequest, request_configuration: Optional[RequestConfiguration[QueryParameters]] = None) -> Optional[GetProjectResponse]:
        """
        PUT_api_v1_projects_projectRef
        param body: The request body
        param request_configuration: Configuration for the request such as headers, query parameters, and middleware options.
        Returns: Optional[GetProjectResponse]
        """
        if body is None:
            raise TypeError("body cannot be null.")
        request_info = self.to_put_request_information(
            body, request_configuration
        )
        if not self.request_adapter:
            raise Exception("Http core is null") 
        from .....models.get_project_response import GetProjectResponse

        return await self.request_adapter.send_async(request_info, GetProjectResponse, None)
    
    def to_delete_request_information(self,request_configuration: Optional[RequestConfiguration[QueryParameters]] = None) -> RequestInformation:
        """
        DELETE_api_v1_projects_projectRef
        param request_configuration: Configuration for the request such as headers, query parameters, and middleware options.
        Returns: RequestInformation
        """
        request_info = RequestInformation(Method.DELETE, self.url_template, self.path_parameters)
        request_info.configure(request_configuration)
        request_info.headers.try_add("Accept", "application/json")
        return request_info
    
    def to_get_request_information(self,request_configuration: Optional[RequestConfiguration[QueryParameters]] = None) -> RequestInformation:
        """
        GET_api_v1_projects_projectRef
        param request_configuration: Configuration for the request such as headers, query parameters, and middleware options.
        Returns: RequestInformation
        """
        request_info = RequestInformation(Method.GET, self.url_template, self.path_parameters)
        request_info.configure(request_configuration)
        request_info.headers.try_add("Accept", "application/json")
        return request_info
    
    def to_put_request_information(self,body: UpdateProjectRequest, request_configuration: Optional[RequestConfiguration[QueryParameters]] = None) -> RequestInformation:
        """
        PUT_api_v1_projects_projectRef
        param body: The request body
        param request_configuration: Configuration for the request such as headers, query parameters, and middleware options.
        Returns: RequestInformation
        """
        if body is None:
            raise TypeError("body cannot be null.")
        request_info = RequestInformation(Method.PUT, self.url_template, self.path_parameters)
        request_info.configure(request_configuration)
        request_info.headers.try_add("Accept", "application/json")
        request_info.set_content_from_parsable(self.request_adapter, "application/json", body)
        return request_info
    
    def with_url(self,raw_url: str) -> ItemRequestBuilder:
        """
        Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
        param raw_url: The raw URL to use for the request builder.
        Returns: ItemRequestBuilder
        """
        if raw_url is None:
            raise TypeError("raw_url cannot be null.")
        return ItemRequestBuilder(self.request_adapter, raw_url)
    
    @property
    def environments(self) -> EnvironmentsRequestBuilder:
        """
        The environments property
        """
        from .environments.environments_request_builder import EnvironmentsRequestBuilder

        return EnvironmentsRequestBuilder(self.request_adapter, self.path_parameters)
    
    @property
    def export(self) -> ExportRequestBuilder:
        """
        The export property
        """
        from .export.export_request_builder import ExportRequestBuilder

        return ExportRequestBuilder(self.request_adapter, self.path_parameters)
    
    @property
    def global_secret_provider(self) -> GlobalSecretProviderRequestBuilder:
        """
        The globalSecretProvider property
        """
        from .global_secret_provider.global_secret_provider_request_builder import GlobalSecretProviderRequestBuilder

        return GlobalSecretProviderRequestBuilder(self.request_adapter, self.path_parameters)
    
    @property
    def groups(self) -> GroupsRequestBuilder:
        """
        The groups property
        """
        from .groups.groups_request_builder import GroupsRequestBuilder

        return GroupsRequestBuilder(self.request_adapter, self.path_parameters)
    
    @property
    def notifications(self) -> NotificationsRequestBuilder:
        """
        The notifications property
        """
        from .notifications.notifications_request_builder import NotificationsRequestBuilder

        return NotificationsRequestBuilder(self.request_adapter, self.path_parameters)
    
    @property
    def providers(self) -> ProvidersRequestBuilder:
        """
        The providers property
        """
        from .providers.providers_request_builder import ProvidersRequestBuilder

        return ProvidersRequestBuilder(self.request_adapter, self.path_parameters)
    
    @property
    def secret_drift(self) -> SecretDriftRequestBuilder:
        """
        The secretDrift property
        """
        from .secret_drift.secret_drift_request_builder import SecretDriftRequestBuilder

        return SecretDriftRequestBuilder(self.request_adapter, self.path_parameters)
    
    @property
    def secrets(self) -> SecretsRequestBuilder:
        """
        The secrets property
        """
        from .secrets.secrets_request_builder import SecretsRequestBuilder

        return SecretsRequestBuilder(self.request_adapter, self.path_parameters)
    
    @property
    def security(self) -> SecurityRequestBuilder:
        """
        The security property
        """
        from .security.security_request_builder import SecurityRequestBuilder

        return SecurityRequestBuilder(self.request_adapter, self.path_parameters)
    
    @property
    def users(self) -> UsersRequestBuilder:
        """
        The users property
        """
        from .users.users_request_builder import UsersRequestBuilder

        return UsersRequestBuilder(self.request_adapter, self.path_parameters)
    
    @property
    def webhooks(self) -> WebhooksRequestBuilder:
        """
        The webhooks property
        """
        from .webhooks.webhooks_request_builder import WebhooksRequestBuilder

        return WebhooksRequestBuilder(self.request_adapter, self.path_parameters)
    
    @dataclass
    class ItemRequestBuilderDeleteRequestConfiguration(RequestConfiguration[QueryParameters]):
        """
        Configuration for the request such as headers, query parameters, and middleware options.
        """
        warn("This class is deprecated. Please use the generic RequestConfiguration class generated by the generator.", DeprecationWarning)
    
    @dataclass
    class ItemRequestBuilderGetRequestConfiguration(RequestConfiguration[QueryParameters]):
        """
        Configuration for the request such as headers, query parameters, and middleware options.
        """
        warn("This class is deprecated. Please use the generic RequestConfiguration class generated by the generator.", DeprecationWarning)
    
    @dataclass
    class ItemRequestBuilderPutRequestConfiguration(RequestConfiguration[QueryParameters]):
        """
        Configuration for the request such as headers, query parameters, and middleware options.
        """
        warn("This class is deprecated. Please use the generic RequestConfiguration class generated by the generator.", DeprecationWarning)
    




from __future__ import annotations
import datetime
from collections.abc import Callable
from dataclasses import dataclass, field
from kiota_abstractions.serialization import AdditionalDataHolder, Parsable, ParseNode, SerializationWriter
from typing import Any, Optional, TYPE_CHECKING, Union
from uuid import UUID

@dataclass
class SshLogEntry(AdditionalDataHolder, Parsable):
    # Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
    additional_data: dict[str, Any] = field(default_factory=dict)

    # The action property
    action: Optional[str] = None
    # The actorType property
    actor_type: Optional[str] = None
    # The apiKeyId property
    api_key_id: Optional[UUID] = None
    # The apiKeyName property
    api_key_name: Optional[str] = None
    # The appClient property
    app_client: Optional[str] = None
    # The certSerial property
    cert_serial: Optional[str] = None
    # The city property
    city: Optional[str] = None
    # The country property
    country: Optional[str] = None
    # The environmentId property
    environment_id: Optional[UUID] = None
    # The environmentSlug property
    environment_slug: Optional[str] = None
    # The id property
    id: Optional[UUID] = None
    # The ipAddress property
    ip_address: Optional[str] = None
    # The keyFingerprint property
    key_fingerprint: Optional[str] = None
    # The projectId property
    project_id: Optional[UUID] = None
    # The projectSlug property
    project_slug: Optional[str] = None
    # The roleName property
    role_name: Optional[str] = None
    # The timestamp property
    timestamp: Optional[datetime.datetime] = None
    # The ttl property
    ttl: Optional[str] = None
    # The userAgent property
    user_agent: Optional[str] = None
    # The userId property
    user_id: Optional[UUID] = None
    # The userName property
    user_name: Optional[str] = None
    
    @staticmethod
    def create_from_discriminator_value(parse_node: ParseNode) -> SshLogEntry:
        """
        Creates a new instance of the appropriate class based on discriminator value
        param parse_node: The parse node to use to read the discriminator value and create the object
        Returns: SshLogEntry
        """
        if parse_node is None:
            raise TypeError("parse_node cannot be null.")
        return SshLogEntry()
    
    def get_field_deserializers(self,) -> dict[str, Callable[[ParseNode], None]]:
        """
        The deserialization information for the current model
        Returns: dict[str, Callable[[ParseNode], None]]
        """
        fields: dict[str, Callable[[Any], None]] = {
            "action": lambda n : setattr(self, 'action', n.get_str_value()),
            "actorType": lambda n : setattr(self, 'actor_type', n.get_str_value()),
            "apiKeyId": lambda n : setattr(self, 'api_key_id', n.get_uuid_value()),
            "apiKeyName": lambda n : setattr(self, 'api_key_name', n.get_str_value()),
            "appClient": lambda n : setattr(self, 'app_client', n.get_str_value()),
            "certSerial": lambda n : setattr(self, 'cert_serial', n.get_str_value()),
            "city": lambda n : setattr(self, 'city', n.get_str_value()),
            "country": lambda n : setattr(self, 'country', n.get_str_value()),
            "environmentId": lambda n : setattr(self, 'environment_id', n.get_uuid_value()),
            "environmentSlug": lambda n : setattr(self, 'environment_slug', n.get_str_value()),
            "id": lambda n : setattr(self, 'id', n.get_uuid_value()),
            "ipAddress": lambda n : setattr(self, 'ip_address', n.get_str_value()),
            "keyFingerprint": lambda n : setattr(self, 'key_fingerprint', n.get_str_value()),
            "projectId": lambda n : setattr(self, 'project_id', n.get_uuid_value()),
            "projectSlug": lambda n : setattr(self, 'project_slug', n.get_str_value()),
            "roleName": lambda n : setattr(self, 'role_name', n.get_str_value()),
            "timestamp": lambda n : setattr(self, 'timestamp', n.get_datetime_value()),
            "ttl": lambda n : setattr(self, 'ttl', n.get_str_value()),
            "userAgent": lambda n : setattr(self, 'user_agent', n.get_str_value()),
            "userId": lambda n : setattr(self, 'user_id', n.get_uuid_value()),
            "userName": lambda n : setattr(self, 'user_name', n.get_str_value()),
        }
        return fields
    
    def serialize(self,writer: SerializationWriter) -> None:
        """
        Serializes information the current object
        param writer: Serialization writer to use to serialize this model
        Returns: None
        """
        if writer is None:
            raise TypeError("writer cannot be null.")
        writer.write_str_value("action", self.action)
        writer.write_str_value("actorType", self.actor_type)
        writer.write_uuid_value("apiKeyId", self.api_key_id)
        writer.write_str_value("apiKeyName", self.api_key_name)
        writer.write_str_value("appClient", self.app_client)
        writer.write_str_value("certSerial", self.cert_serial)
        writer.write_str_value("city", self.city)
        writer.write_str_value("country", self.country)
        writer.write_uuid_value("environmentId", self.environment_id)
        writer.write_str_value("environmentSlug", self.environment_slug)
        writer.write_uuid_value("id", self.id)
        writer.write_str_value("ipAddress", self.ip_address)
        writer.write_str_value("keyFingerprint", self.key_fingerprint)
        writer.write_uuid_value("projectId", self.project_id)
        writer.write_str_value("projectSlug", self.project_slug)
        writer.write_str_value("roleName", self.role_name)
        writer.write_datetime_value("timestamp", self.timestamp)
        writer.write_str_value("ttl", self.ttl)
        writer.write_str_value("userAgent", self.user_agent)
        writer.write_uuid_value("userId", self.user_id)
        writer.write_str_value("userName", self.user_name)
        writer.write_additional_data_value(self.additional_data)
    




from __future__ import annotations
from collections.abc import Callable
from dataclasses import dataclass, field
from kiota_abstractions.serialization import AdditionalDataHolder, Parsable, ParseNode, SerializationWriter
from typing import Any, Optional, TYPE_CHECKING, Union
from uuid import UUID

@dataclass
class ChangeTenantPlanResponse(AdditionalDataHolder, Parsable):
    # Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
    additional_data: dict[str, Any] = field(default_factory=dict)

    # The message property
    message: Optional[str] = None
    # The plan property
    plan: Optional[str] = None
    # The tenantId property
    tenant_id: Optional[UUID] = None
    
    @staticmethod
    def create_from_discriminator_value(parse_node: ParseNode) -> ChangeTenantPlanResponse:
        """
        Creates a new instance of the appropriate class based on discriminator value
        param parse_node: The parse node to use to read the discriminator value and create the object
        Returns: ChangeTenantPlanResponse
        """
        if parse_node is None:
            raise TypeError("parse_node cannot be null.")
        return ChangeTenantPlanResponse()
    
    def get_field_deserializers(self,) -> dict[str, Callable[[ParseNode], None]]:
        """
        The deserialization information for the current model
        Returns: dict[str, Callable[[ParseNode], None]]
        """
        fields: dict[str, Callable[[Any], None]] = {
            "message": lambda n : setattr(self, 'message', n.get_str_value()),
            "plan": lambda n : setattr(self, 'plan', n.get_str_value()),
            "tenantId": lambda n : setattr(self, 'tenant_id', n.get_uuid_value()),
        }
        return fields
    
    def serialize(self,writer: SerializationWriter) -> None:
        """
        Serializes information the current object
        param writer: Serialization writer to use to serialize this model
        Returns: None
        """
        if writer is None:
            raise TypeError("writer cannot be null.")
        writer.write_str_value("message", self.message)
        writer.write_str_value("plan", self.plan)
        writer.write_uuid_value("tenantId", self.tenant_id)
        writer.write_additional_data_value(self.additional_data)
    




"""
bella-baxter — Python SDK

Minimal client for the Bella Baxter secret management API.
Supports both synchronous and async usage via httpx.

Sync usage:
    from bella_baxter import BaxterClient, BaxterClientOptions

    client = BaxterClient(BaxterClientOptions(
        baxter_url="https://api.bella-baxter.io",
        api_key="bax-abc123",
    ))
    secrets = client.get_all_secrets("production")

Async usage:
    async with BaxterClient.async_client(options) as client:
        secrets = await client.get_all_secrets_async("production")
"""

from .client import BaxterClient
from .models import (
    BaxterClientOptions,
    AllEnvironmentSecretsResponse,
    EnvironmentSecretsVersionResponse,
)
from .webhook_signature import verify_webhook_signature

__all__ = [
    "BaxterClient",
    "BaxterClientOptions",
    "AllEnvironmentSecretsResponse",
    "EnvironmentSecretsVersionResponse",
    "verify_webhook_signature",
]



from __future__ import annotations
import datetime
from collections.abc import Callable
from dataclasses import dataclass, field
from kiota_abstractions.serialization import AdditionalDataHolder, Parsable, ParseNode, SerializationWriter
from typing import Any, Optional, TYPE_CHECKING, Union

if TYPE_CHECKING:
    from .secret_manifest_item import SecretManifestItem

@dataclass
class SecretsManifest(AdditionalDataHolder, Parsable):
    # Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
    additional_data: dict[str, Any] = field(default_factory=dict)

    # The environmentSlug property
    environment_slug: Optional[str] = None
    # The generatedAt property
    generated_at: Optional[datetime.datetime] = None
    # The projectSlug property
    project_slug: Optional[str] = None
    # The secrets property
    secrets: Optional[list[SecretManifestItem]] = None
    
    @staticmethod
    def create_from_discriminator_value(parse_node: ParseNode) -> SecretsManifest:
        """
        Creates a new instance of the appropriate class based on discriminator value
        param parse_node: The parse node to use to read the discriminator value and create the object
        Returns: SecretsManifest
        """
        if parse_node is None:
            raise TypeError("parse_node cannot be null.")
        return SecretsManifest()
    
    def get_field_deserializers(self,) -> dict[str, Callable[[ParseNode], None]]:
        """
        The deserialization information for the current model
        Returns: dict[str, Callable[[ParseNode], None]]
        """
        from .secret_manifest_item import SecretManifestItem

        from .secret_manifest_item import SecretManifestItem

        fields: dict[str, Callable[[Any], None]] = {
            "environmentSlug": lambda n : setattr(self, 'environment_slug', n.get_str_value()),
            "generatedAt": lambda n : setattr(self, 'generated_at', n.get_datetime_value()),
            "projectSlug": lambda n : setattr(self, 'project_slug', n.get_str_value()),
            "secrets": lambda n : setattr(self, 'secrets', n.get_collection_of_object_values(SecretManifestItem)),
        }
        return fields
    
    def serialize(self,writer: SerializationWriter) -> None:
        """
        Serializes information the current object
        param writer: Serialization writer to use to serialize this model
        Returns: None
        """
        if writer is None:
            raise TypeError("writer cannot be null.")
        writer.write_str_value("environmentSlug", self.environment_slug)
        writer.write_datetime_value("generatedAt", self.generated_at)
        writer.write_str_value("projectSlug", self.project_slug)
        writer.write_collection_of_object_values("secrets", self.secrets)
        writer.write_additional_data_value(self.additional_data)
    




from __future__ import annotations
import datetime
from collections.abc import Callable
from dataclasses import dataclass, field
from kiota_abstractions.serialization import AdditionalDataHolder, Parsable, ParseNode, SerializationWriter
from typing import Any, Optional, TYPE_CHECKING, Union
from uuid import UUID

@dataclass
class ShareListItem(AdditionalDataHolder, Parsable):
    # Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
    additional_data: dict[str, Any] = field(default_factory=dict)

    # The createdAt property
    created_at: Optional[datetime.datetime] = None
    # The expiresAt property
    expires_at: Optional[datetime.datetime] = None
    # The hasPassword property
    has_password: Optional[bool] = None
    # The isRevoked property
    is_revoked: Optional[bool] = None
    # The label property
    label: Optional[str] = None
    # The maxViews property
    max_views: Optional[int] = None
    # The shareId property
    share_id: Optional[UUID] = None
    # The viewCount property
    view_count: Optional[int] = None
    
    @staticmethod
    def create_from_discriminator_value(parse_node: ParseNode) -> ShareListItem:
        """
        Creates a new instance of the appropriate class based on discriminator value
        param parse_node: The parse node to use to read the discriminator value and create the object
        Returns: ShareListItem
        """
        if parse_node is None:
            raise TypeError("parse_node cannot be null.")
        return ShareListItem()
    
    def get_field_deserializers(self,) -> dict[str, Callable[[ParseNode], None]]:
        """
        The deserialization information for the current model
        Returns: dict[str, Callable[[ParseNode], None]]
        """
        fields: dict[str, Callable[[Any], None]] = {
            "createdAt": lambda n : setattr(self, 'created_at', n.get_datetime_value()),
            "expiresAt": lambda n : setattr(self, 'expires_at', n.get_datetime_value()),
            "hasPassword": lambda n : setattr(self, 'has_password', n.get_bool_value()),
            "isRevoked": lambda n : setattr(self, 'is_revoked', n.get_bool_value()),
            "label": lambda n : setattr(self, 'label', n.get_str_value()),
            "maxViews": lambda n : setattr(self, 'max_views', n.get_int_value()),
            "shareId": lambda n : setattr(self, 'share_id', n.get_uuid_value()),
            "viewCount": lambda n : setattr(self, 'view_count', n.get_int_value()),
        }
        return fields
    
    def serialize(self,writer: SerializationWriter) -> None:
        """
        Serializes information the current object
        param writer: Serialization writer to use to serialize this model
        Returns: None
        """
        if writer is None:
            raise TypeError("writer cannot be null.")
        writer.write_datetime_value("createdAt", self.created_at)
        writer.write_datetime_value("expiresAt", self.expires_at)
        writer.write_bool_value("hasPassword", self.has_password)
        writer.write_bool_value("isRevoked", self.is_revoked)
        writer.write_str_value("label", self.label)
        writer.write_int_value("maxViews", self.max_views)
        writer.write_uuid_value("shareId", self.share_id)
        writer.write_int_value("viewCount", self.view_count)
        writer.write_additional_data_value(self.additional_data)
    




from __future__ import annotations
from collections.abc import Callable
from dataclasses import dataclass, field
from kiota_abstractions.serialization import AdditionalDataHolder, Parsable, ParseNode, SerializationWriter
from typing import Any, Optional, TYPE_CHECKING, Union

if TYPE_CHECKING:
    from .access_log_entry import AccessLogEntry
    from .activity_by_day import ActivityByDay
    from .dashboard_count_pair import DashboardCountPair

@dataclass
class DashboardResponse(AdditionalDataHolder, Parsable):
    # Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
    additional_data: dict[str, Any] = field(default_factory=dict)

    # The activityByDay property
    activity_by_day: Optional[list[ActivityByDay]] = None
    # The apiKeys property
    api_keys: Optional[DashboardCountPair] = None
    # The environments property
    environments: Optional[DashboardCountPair] = None
    # The projects property
    projects: Optional[DashboardCountPair] = None
    # The providers property
    providers: Optional[int] = None
    # The recentActivity property
    recent_activity: Optional[list[AccessLogEntry]] = None
    # The secrets property
    secrets: Optional[int] = None
    # The users property
    users: Optional[int] = None
    
    @staticmethod
    def create_from_discriminator_value(parse_node: ParseNode) -> DashboardResponse:
        """
        Creates a new instance of the appropriate class based on discriminator value
        param parse_node: The parse node to use to read the discriminator value and create the object
        Returns: DashboardResponse
        """
        if parse_node is None:
            raise TypeError("parse_node cannot be null.")
        return DashboardResponse()
    
    def get_field_deserializers(self,) -> dict[str, Callable[[ParseNode], None]]:
        """
        The deserialization information for the current model
        Returns: dict[str, Callable[[ParseNode], None]]
        """
        from .access_log_entry import AccessLogEntry
        from .activity_by_day import ActivityByDay
        from .dashboard_count_pair import DashboardCountPair

        from .access_log_entry import AccessLogEntry
        from .activity_by_day import ActivityByDay
        from .dashboard_count_pair import DashboardCountPair

        fields: dict[str, Callable[[Any], None]] = {
            "activityByDay": lambda n : setattr(self, 'activity_by_day', n.get_collection_of_object_values(ActivityByDay)),
            "apiKeys": lambda n : setattr(self, 'api_keys', n.get_object_value(DashboardCountPair)),
            "environments": lambda n : setattr(self, 'environments', n.get_object_value(DashboardCountPair)),
            "projects": lambda n : setattr(self, 'projects', n.get_object_value(DashboardCountPair)),
            "providers": lambda n : setattr(self, 'providers', n.get_int_value()),
            "recentActivity": lambda n : setattr(self, 'recent_activity', n.get_collection_of_object_values(AccessLogEntry)),
            "secrets": lambda n : setattr(self, 'secrets', n.get_int_value()),
            "users": lambda n : setattr(self, 'users', n.get_int_value()),
        }
        return fields
    
    def serialize(self,writer: SerializationWriter) -> None:
        """
        Serializes information the current object
        param writer: Serialization writer to use to serialize this model
        Returns: None
        """
        if writer is None:
            raise TypeError("writer cannot be null.")
        writer.write_collection_of_object_values("activityByDay", self.activity_by_day)
        writer.write_object_value("apiKeys", self.api_keys)
        writer.write_object_value("environments", self.environments)
        writer.write_object_value("projects", self.projects)
        writer.write_int_value("providers", self.providers)
        writer.write_collection_of_object_values("recentActivity", self.recent_activity)
        writer.write_int_value("secrets", self.secrets)
        writer.write_int_value("users", self.users)
        writer.write_additional_data_value(self.additional_data)
    




"""webhook_signature — Verify X-Bella-Signature header on incoming Bella Baxter webhooks."""

from __future__ import annotations

import hashlib
import hmac as hmac_mod
import time
from typing import Union


def verify_webhook_signature(
    secret: str,
    signature_header: str,
    raw_body: Union[str, bytes],
    tolerance_seconds: int = 300,
) -> bool:
    """Verify the X-Bella-Signature header on a received Bella Baxter webhook.

    Args:
        secret: The webhook signing secret (whsec-xxx value).
        signature_header: Value of the X-Bella-Signature header,
            e.g. ``"t=1714000000,v1=abc123..."``.
        raw_body: The raw request body as str or bytes.
        tolerance_seconds: Maximum age of the timestamp in seconds. Default 300 (5 min).

    Returns:
        ``True`` if the signature is valid and the timestamp is within the
        replay-protection window; ``False`` otherwise.
    """
    # Parse t= and v1= from header
    timestamp: int | None = None
    expected_sig: str | None = None

    for part in signature_header.split(","):
        if "=" not in part:
            continue
        key, _, value = part.partition("=")
        key = key.strip()
        value = value.strip()
        if key == "t":
            try:
                timestamp = int(value)
            except ValueError:
                return False
        elif key == "v1":
            expected_sig = value

    if timestamp is None or expected_sig is None:
        return False

    # Check timestamp tolerance (replay-attack protection)
    if abs(int(time.time()) - timestamp) > tolerance_seconds:
        return False

    # Normalise body to str; webhook payloads are always UTF-8 JSON
    body_str = raw_body if isinstance(raw_body, str) else raw_body.decode("utf-8")
    signing_input = f"{timestamp}.{body_str}"

    # HMAC-SHA256: key=UTF8(secret), data=UTF8(signing_input)
    computed_sig = hmac_mod.new(
        secret.encode("utf-8"),
        signing_input.encode("utf-8"),
        hashlib.sha256,
    ).hexdigest()

    # Timing-safe compare
    return hmac_mod.compare_digest(computed_sig, expected_sig)



from __future__ import annotations
import datetime
from collections.abc import Callable
from dataclasses import dataclass, field
from kiota_abstractions.serialization import AdditionalDataHolder, Parsable, ParseNode, SerializationWriter
from typing import Any, Optional, TYPE_CHECKING, Union

if TYPE_CHECKING:
    from .all_environment_secrets_response_secrets import AllEnvironmentSecretsResponse_secrets

@dataclass
class AllEnvironmentSecretsResponse(AdditionalDataHolder, Parsable):
    # Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
    additional_data: dict[str, Any] = field(default_factory=dict)

    # The environmentName property
    environment_name: Optional[str] = None
    # The environmentSlug property
    environment_slug: Optional[str] = None
    # The lastModified property
    last_modified: Optional[datetime.datetime] = None
    # The secrets property
    secrets: Optional[AllEnvironmentSecretsResponse_secrets] = None
    # The version property
    version: Optional[int] = None
    
    @staticmethod
    def create_from_discriminator_value(parse_node: ParseNode) -> AllEnvironmentSecretsResponse:
        """
        Creates a new instance of the appropriate class based on discriminator value
        param parse_node: The parse node to use to read the discriminator value and create the object
        Returns: AllEnvironmentSecretsResponse
        """
        if parse_node is None:
            raise TypeError("parse_node cannot be null.")
        return AllEnvironmentSecretsResponse()
    
    def get_field_deserializers(self,) -> dict[str, Callable[[ParseNode], None]]:
        """
        The deserialization information for the current model
        Returns: dict[str, Callable[[ParseNode], None]]
        """
        from .all_environment_secrets_response_secrets import AllEnvironmentSecretsResponse_secrets

        from .all_environment_secrets_response_secrets import AllEnvironmentSecretsResponse_secrets

        fields: dict[str, Callable[[Any], None]] = {
            "environmentName": lambda n : setattr(self, 'environment_name', n.get_str_value()),
            "environmentSlug": lambda n : setattr(self, 'environment_slug', n.get_str_value()),
            "lastModified": lambda n : setattr(self, 'last_modified', n.get_datetime_value()),
            "secrets": lambda n : setattr(self, 'secrets', n.get_object_value(AllEnvironmentSecretsResponse_secrets)),
            "version": lambda n : setattr(self, 'version', n.get_int_value()),
        }
        return fields
    
    def serialize(self,writer: SerializationWriter) -> None:
        """
        Serializes information the current object
        param writer: Serialization writer to use to serialize this model
        Returns: None
        """
        if writer is None:
            raise TypeError("writer cannot be null.")
        writer.write_str_value("environmentName", self.environment_name)
        writer.write_str_value("environmentSlug", self.environment_slug)
        writer.write_datetime_value("lastModified", self.last_modified)
        writer.write_object_value("secrets", self.secrets)
        writer.write_int_value("version", self.version)
        writer.write_additional_data_value(self.additional_data)
    




from __future__ import annotations
from collections.abc import Callable
from dataclasses import dataclass, field
from kiota_abstractions.serialization import AdditionalDataHolder, Parsable, ParseNode, SerializationWriter
from typing import Any, Optional, TYPE_CHECKING, Union

if TYPE_CHECKING:
    from .ssh_log_entry import SshLogEntry

@dataclass
class SshLogPage(AdditionalDataHolder, Parsable):
    # Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
    additional_data: dict[str, Any] = field(default_factory=dict)

    # The items property
    items: Optional[list[SshLogEntry]] = None
    # The page property
    page: Optional[int] = None
    # The size property
    size: Optional[int] = None
    # The totalCount property
    total_count: Optional[int] = None
    
    @staticmethod
    def create_from_discriminator_value(parse_node: ParseNode) -> SshLogPage:
        """
        Creates a new instance of the appropriate class based on discriminator value
        param parse_node: The parse node to use to read the discriminator value and create the object
        Returns: SshLogPage
        """
        if parse_node is None:
            raise TypeError("parse_node cannot be null.")
        return SshLogPage()
    
    def get_field_deserializers(self,) -> dict[str, Callable[[ParseNode], None]]:
        """
        The deserialization information for the current model
        Returns: dict[str, Callable[[ParseNode], None]]
        """
        from .ssh_log_entry import SshLogEntry

        from .ssh_log_entry import SshLogEntry

        fields: dict[str, Callable[[Any], None]] = {
            "items": lambda n : setattr(self, 'items', n.get_collection_of_object_values(SshLogEntry)),
            "page": lambda n : setattr(self, 'page', n.get_int_value()),
            "size": lambda n : setattr(self, 'size', n.get_int_value()),
            "totalCount": lambda n : setattr(self, 'total_count', n.get_int_value()),
        }
        return fields
    
    def serialize(self,writer: SerializationWriter) -> None:
        """
        Serializes information the current object
        param writer: Serialization writer to use to serialize this model
        Returns: None
        """
        if writer is None:
            raise TypeError("writer cannot be null.")
        writer.write_collection_of_object_values("items", self.items)
        writer.write_int_value("page", self.page)
        writer.write_int_value("size", self.size)
        writer.write_int_value("totalCount", self.total_count)
        writer.write_additional_data_value(self.additional_data)
    




from __future__ import annotations
import datetime
from collections.abc import Callable
from dataclasses import dataclass, field
from kiota_abstractions.serialization import AdditionalDataHolder, Parsable, ParseNode, SerializationWriter
from typing import Any, Optional, TYPE_CHECKING, Union

if TYPE_CHECKING:
    from .sso_status_response_config import SsoStatusResponse_config

@dataclass
class SsoStatusResponse(AdditionalDataHolder, Parsable):
    # Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
    additional_data: dict[str, Any] = field(default_factory=dict)

    # The approvalStatus property
    approval_status: Optional[str] = None
    # The config property
    config: Optional[SsoStatusResponse_config] = None
    # The rejectionReason property
    rejection_reason: Optional[str] = None
    # The requestedAt property
    requested_at: Optional[datetime.datetime] = None
    
    @staticmethod
    def create_from_discriminator_value(parse_node: ParseNode) -> SsoStatusResponse:
        """
        Creates a new instance of the appropriate class based on discriminator value
        param parse_node: The parse node to use to read the discriminator value and create the object
        Returns: SsoStatusResponse
        """
        if parse_node is None:
            raise TypeError("parse_node cannot be null.")
        return SsoStatusResponse()
    
    def get_field_deserializers(self,) -> dict[str, Callable[[ParseNode], None]]:
        """
        The deserialization information for the current model
        Returns: dict[str, Callable[[ParseNode], None]]
        """
        from .sso_status_response_config import SsoStatusResponse_config

        from .sso_status_response_config import SsoStatusResponse_config

        fields: dict[str, Callable[[Any], None]] = {
            "approvalStatus": lambda n : setattr(self, 'approval_status', n.get_str_value()),
            "config": lambda n : setattr(self, 'config', n.get_object_value(SsoStatusResponse_config)),
            "rejectionReason": lambda n : setattr(self, 'rejection_reason', n.get_str_value()),
            "requestedAt": lambda n : setattr(self, 'requested_at', n.get_datetime_value()),
        }
        return fields
    
    def serialize(self,writer: SerializationWriter) -> None:
        """
        Serializes information the current object
        param writer: Serialization writer to use to serialize this model
        Returns: None
        """
        if writer is None:
            raise TypeError("writer cannot be null.")
        writer.write_str_value("approvalStatus", self.approval_status)
        writer.write_object_value("config", self.config)
        writer.write_str_value("rejectionReason", self.rejection_reason)
        writer.write_datetime_value("requestedAt", self.requested_at)
        writer.write_additional_data_value(self.additional_data)
    

